==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RecreateDeploymentStrategyParamsBuilder extends io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams,io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsBuilder>{
  public RecreateDeploymentStrategyParamsBuilder() {
    this(false);
  }
  public RecreateDeploymentStrategyParamsBuilder(java.lang.Boolean validationEnabled) {
    this(new RecreateDeploymentStrategyParams(), validationEnabled);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent) {
    this(fluent, false);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RecreateDeploymentStrategyParams(), validationEnabled);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance) {
    this(fluent, instance, false);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMid(instance.getMid()); 
    fluent.withPost(instance.getPost()); 
    fluent.withPre(instance.getPre()); 
    fluent.withTimeoutSeconds(instance.getTimeoutSeconds()); 
    this.validationEnabled = validationEnabled; 
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance) {
    this(instance,false);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMid(instance.getMid()); 
    this.withPost(instance.getPost()); 
    this.withPre(instance.getPre()); 
    this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams build() {
    RecreateDeploymentStrategyParams buildable = new RecreateDeploymentStrategyParams(fluent.getMid(),fluent.getPost(),fluent.getPre(),fluent.getTimeoutSeconds());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RecreateDeploymentStrategyParamsBuilder that = (RecreateDeploymentStrategyParamsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RecreateDeploymentStrategyParamsBuilder extends io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams,io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsBuilder>{
  public RecreateDeploymentStrategyParamsBuilder() {
    this(false);
  }
  public RecreateDeploymentStrategyParamsBuilder(java.lang.Boolean validationEnabled) {
    this(new RecreateDeploymentStrategyParams(), validationEnabled);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent) {
    this(fluent, false);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RecreateDeploymentStrategyParams(), validationEnabled);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance) {
    this(fluent, instance, false);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMid(instance.getMid()); 
    fluent.withPost(instance.getPost()); 
    fluent.withPre(instance.getPre()); 
    fluent.withTimeoutSeconds(instance.getTimeoutSeconds()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance) {
    this(instance,false);
  }
  public RecreateDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMid(instance.getMid()); 
    this.withPost(instance.getPost()); 
    this.withPre(instance.getPre()); 
    this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams build() {
    RecreateDeploymentStrategyParams buildable = new RecreateDeploymentStrategyParams(fluent.getMid(),fluent.getPost(),fluent.getPre(),fluent.getTimeoutSeconds());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RecreateDeploymentStrategyParamsBuilder that = (RecreateDeploymentStrategyParamsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
